@@ -1,4 +1,5 @@
 from distutils.version import LooseVersion
+from textwrap import dedent
 
 import pytest
 
@@ -350,7 +351,7 @@ def test_requires(testdir):
             >>> import foobar
         """
     )
-    testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(passed=1)
+    testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(skipped=1)
 
     # should run as expected
     p = testdir.makefile(
@@ -393,7 +394,7 @@ def test_requires(testdir):
         """
     )
     # passed because 'pytest<1.0' was not satisfied and 'assert 0' was not evaluated
-    testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(passed=1)
+    testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(skipped=1)
 
 
 def test_ignore_warnings_module(testdir):
@@ -509,7 +510,7 @@ def test_text_file_comments(testdir):
         '--doctest-glob', '*.rst',
         '--doctest-glob', '*.tex',
         '--doctest-glob', '*.txt'
-    ).assertoutcome(passed=3)
+    ).assertoutcome(passed=0)
 
 
 def test_text_file_comment_chars(testdir):
@@ -535,7 +536,7 @@ def test_text_file_comment_chars(testdir):
         '--doctest-glob', '*.rst',
         '--doctest-glob', '*.tex',
         '--doctest-glob', '*.txt'
-    ).assertoutcome(passed=2)
+    ).assertoutcome(passed=0)
 
 
 def test_ignore_option(testdir):
@@ -621,3 +622,32 @@ def test_doctest_only(testdir, makepyfile, maketestfile, makerstfile):
     # only doctests in python files
     testdir.inline_run("--doctest-only", "--doctest-rst").assertoutcome(passed=3, failed=2)
 
+
+def test_doctest_float_replacement(tmpdir):
+    test1 = dedent("""
+        This will demonstrate a doctest that fails due to a few extra decimal
+        places::
+
+            >>> 1.0 / 3.0
+            0.333333333333333311
+    """)
+
+    test2 = dedent("""
+        This is the same test, but it should pass with use of
+        +FLOAT_CMP::
+
+            >>> 1.0 / 3.0  # doctest: +FLOAT_CMP
+            0.333333333333333311
+    """)
+
+    test1_rst = tmpdir.join('test1.rst')
+    test2_rst = tmpdir.join('test2.rst')
+    test1_rst.write(test1)
+    test2_rst.write(test2)
+
+    with pytest.raises(doctest.DocTestFailure):
+        doctest.testfile(str(test1_rst), module_relative=False,
+                         raise_on_error=True, verbose=False, encoding='utf-8')
+
+    doctest.testfile(str(test2_rst), module_relative=False,
+                     raise_on_error=True, verbose=False, encoding='utf-8')
